@@ -1,7 +1,7 @@
 from typing import List
 from pydantic import BaseModel
 
-from scene import Scene
+from .scene import Scene
 
 
 
